pub struct CmaEs<F> {
pub state: CmaEsState,
pub bounds: Option<MultiBounds>,
/* private fields */
}Expand description
CMA-ES optimizer
Fields
state: CmaEsStateState of the optimizer
bounds: Option<MultiBounds>Problem bounds
Implementations
Sourceimpl<F: CmaEsFitness> CmaEs<F>
impl<F: CmaEsFitness> CmaEs<F>
Sourcepub fn with_lambda(
initial_mean: Vec<f64>,
initial_sigma: f64,
lambda: usize,
) -> Self
pub fn with_lambda( initial_mean: Vec<f64>, initial_sigma: f64, lambda: usize, ) -> Self
Create with custom population size
Sourcepub fn with_bounds(self, bounds: MultiBounds) -> Self
pub fn with_bounds(self, bounds: MultiBounds) -> Self
Set problem bounds
Sourcepub fn step<R: Rng>(
&mut self,
fitness: &F,
rng: &mut R,
) -> EvoResult<Vec<Individual<RealVector>>>
pub fn step<R: Rng>( &mut self, fitness: &F, rng: &mut R, ) -> EvoResult<Vec<Individual<RealVector>>>
Run a single generation
Sourcepub fn run_generations<R: Rng>(
&mut self,
fitness: &F,
max_generations: usize,
rng: &mut R,
) -> EvoResult<Individual<RealVector>>
pub fn run_generations<R: Rng>( &mut self, fitness: &F, max_generations: usize, rng: &mut R, ) -> EvoResult<Individual<RealVector>>
Run the optimizer for a fixed number of generations
Sourcepub fn run_until<R: Rng>(
&mut self,
fitness: &F,
target_fitness: f64,
max_generations: usize,
rng: &mut R,
) -> EvoResult<Individual<RealVector>>
pub fn run_until<R: Rng>( &mut self, fitness: &F, target_fitness: f64, max_generations: usize, rng: &mut R, ) -> EvoResult<Individual<RealVector>>
Run the optimizer until a target fitness is reached or max generations
Sourcepub fn generation(&self) -> usize
pub fn generation(&self) -> usize
Get the current generation
Sourcepub fn evaluations(&self) -> usize
pub fn evaluations(&self) -> usize
Get total evaluations
Sourcepub fn best_solution(&self) -> &[f64]
pub fn best_solution(&self) -> &[f64]
Get the best solution found
Sourcepub fn best_fitness(&self) -> f64
pub fn best_fitness(&self) -> f64
Get the best fitness found