pub struct SteadyStateGA<G, F, S, C, M, Fit, Term>where
G: EvolutionaryGenome,
F: FitnessValue,{ /* private fields */ }Expand description
Steady-State Genetic Algorithm
A GA variant that replaces only a few individuals per generation step, maintaining a more continuous population transition.
Implementations
Sourceimpl<G, F, S, C, M, Fit, Term> SteadyStateGA<G, F, S, C, M, Fit, Term>where
G: EvolutionaryGenome + Send + Sync,
F: FitnessValue + Send,
S: SelectionOperator<G>,
C: CrossoverOperator<G>,
M: MutationOperator<G>,
Fit: Fitness<Genome = G, Value = F> + Sync,
Term: TerminationCriterion<G, F>,
impl<G, F, S, C, M, Fit, Term> SteadyStateGA<G, F, S, C, M, Fit, Term>where
G: EvolutionaryGenome + Send + Sync,
F: FitnessValue + Send,
S: SelectionOperator<G>,
C: CrossoverOperator<G>,
M: MutationOperator<G>,
Fit: Fitness<Genome = G, Value = F> + Sync,
Term: TerminationCriterion<G, F>,
Sourcepub fn builder() -> SteadyStateBuilder<G, F, (), (), (), (), ()>
pub fn builder() -> SteadyStateBuilder<G, F, (), (), (), (), ()>
Create a builder for SteadyStateGA
Sourcepub fn run<R: Rng>(
&self,
rng: &mut R,
) -> Result<EvolutionResult<G, F>, EvolutionError>
pub fn run<R: Rng>( &self, rng: &mut R, ) -> Result<EvolutionResult<G, F>, EvolutionError>
Run the steady-state genetic algorithm
Sourceimpl<G, F, S, C, M, Fit, Term> SteadyStateGA<G, F, S, C, M, Fit, Term>where
G: EvolutionaryGenome + Send + Sync,
F: FitnessValue + Send,
S: SelectionOperator<G>,
C: BoundedCrossoverOperator<G>,
M: BoundedMutationOperator<G>,
Fit: Fitness<Genome = G, Value = F> + Sync,
Term: TerminationCriterion<G, F>,
impl<G, F, S, C, M, Fit, Term> SteadyStateGA<G, F, S, C, M, Fit, Term>where
G: EvolutionaryGenome + Send + Sync,
F: FitnessValue + Send,
S: SelectionOperator<G>,
C: BoundedCrossoverOperator<G>,
M: BoundedMutationOperator<G>,
Fit: Fitness<Genome = G, Value = F> + Sync,
Term: TerminationCriterion<G, F>,
Sourcepub fn run_bounded<R: Rng>(
&self,
rng: &mut R,
) -> Result<EvolutionResult<G, F>, EvolutionError>
pub fn run_bounded<R: Rng>( &self, rng: &mut R, ) -> Result<EvolutionResult<G, F>, EvolutionError>
Run the steady-state genetic algorithm with bounded operators