pub fn load_checkpoint<G>(
path: impl AsRef<Path>,
) -> Result<Checkpoint<G>, CheckpointError>Expand description
Load a checkpoint from a file using the default size limit
(DEFAULT_MAX_CHECKPOINT_BYTES).
pub fn load_checkpoint<G>(
path: impl AsRef<Path>,
) -> Result<Checkpoint<G>, CheckpointError>Load a checkpoint from a file using the default size limit
(DEFAULT_MAX_CHECKPOINT_BYTES).