CrossoverMask

Trait CrossoverMask 

pub trait CrossoverMask: Send + Sync {
    // Required method
    fn from_parent1(&self, addr: &Address) -> bool;
}
Trait for determining which parent contributes to each address during crossover

Required Methods

fn from_parent1(&self, addr: &Address) -> bool

Returns true if parent1’s value should be used at the given address

Implementors