TreeNode

Enum TreeNode 

pub enum TreeNode<T: Terminal, F: Function> {
    Terminal(T),
    Function(F, Vec<TreeNode<T, F>>),
}
A node in a GP tree

Variants



Terminal(T)

Terminal node (leaf)



Function(F, Vec<TreeNode<T, F>>)

Function node (internal)

Implementations

Source

impl<T: Terminal, F: Function> TreeNode<T, F>

pub fn terminal(value: T) -> Self

Create a new terminal node

pub fn function(func: F, children: Vec<Self>) -> Self

Create a new function node

pub fn is_terminal(&self) -> bool

Check if this is a terminal node

pub fn is_function(&self) -> bool

Check if this is a function node

pub fn depth(&self) -> usize

Get the depth of this subtree.

Uses an explicit work stack rather than recursion so that pathologically deep trees cannot overflow the call stack (see the module note on deep trees).

pub fn size(&self) -> usize

Get the number of nodes in this subtree.

Uses an explicit work stack rather than recursion (see the module note on deep trees).

pub fn positions(&self) -> Vec<Vec<usize>>

Get all node positions (preorder traversal indices)

pub fn get_subtree(&self, path: &[usize]) -> Option<&Self>

Get a subtree at the given path

pub fn get_subtree_mut(&mut self, path: &[usize]) -> Option<&mut Self>

Get a mutable subtree at the given path

pub fn replace_subtree(&mut self, path: &[usize], new_subtree: Self) -> bool

Replace a subtree at the given path

pub fn terminal_positions(&self) -> Vec<Vec<usize>>

Get all terminal positions

pub fn function_positions(&self) -> Vec<Vec<usize>>

Get all function positions