pub struct CandidateId(pub usize);Expand description
Unique identifier for a candidate in an interactive session
Each candidate is assigned a unique ID when created, which remains stable across generations. This allows tracking evaluation history and aggregating feedback over time.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for CandidateId
impl Clone for CandidateId
Sourcefn clone(&self) -> CandidateId
fn clone(&self) -> CandidateId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CandidateId
impl Debug for CandidateId
Sourceimpl<'de> Deserialize<'de> for CandidateId
impl<'de> Deserialize<'de> for CandidateId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for CandidateId
impl Display for CandidateId
Sourceimpl From<CandidateId> for usize
impl From<CandidateId> for usize
Sourcefn from(id: CandidateId) -> Self
fn from(id: CandidateId) -> Self
Converts to this type from the input type.
Sourceimpl From<usize> for CandidateId
impl From<usize> for CandidateId
Sourceimpl Hash for CandidateId
impl Hash for CandidateId
Sourceimpl Ord for CandidateId
impl Ord for CandidateId
Sourcefn cmp(&self, other: &CandidateId) -> Ordering
fn cmp(&self, other: &CandidateId) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CandidateId
impl PartialEq for CandidateId
Sourceimpl PartialOrd for CandidateId
impl PartialOrd for CandidateId
Sourceimpl Serialize for CandidateId
impl Serialize for CandidateId
impl Copy for CandidateId
impl Eq for CandidateId
impl StructuralPartialEq for CandidateId