DefaultInteractiveFitness

Struct DefaultInteractiveFitness 

pub struct DefaultInteractiveFitness<G>{ /* private fields */ }
Default interactive fitness implementation using a fixed evaluation mode

This provides a simple implementation that delegates all processing to the fitness aggregator. Suitable for most use cases.

Implementations

Source

impl<G> DefaultInteractiveFitness<G>

pub fn new(mode: EvaluationMode) -> Self

Create a new default interactive fitness with the given mode

pub fn with_batch_size(self, size: usize) -> Self

Set the batch size for batch selection mode

pub fn with_select_count(self, count: usize) -> Self

Set how many candidates to select in batch selection mode