pub struct OxCrossover;Expand description
Order Crossover (OX) for permutation genomes
OX preserves the relative order of elements from one parent while copying a segment from the other parent.
Reference: Davis, L. (1985). Applying Adaptive Algorithms to Epistatic Domains. IJCAI.
Implementations
Sourceimpl OxCrossover
impl OxCrossover