pub struct ShrinkMutation;Expand description
Shrink mutation for tree genomes (genetic programming)
Replaces a randomly selected subtree with one of its terminals. This reduces tree size and helps with bloat control.
Implementations