pub struct SubtreeMutation {
pub max_subtree_depth: usize,
pub function_probability: f64,
pub terminal_probability: f64,
}Expand description
Subtree mutation for tree genomes (genetic programming)
Replaces a randomly selected subtree with a new randomly generated subtree. This is a more disruptive mutation than point mutation.
Fields
max_subtree_depth: usizeMaximum depth of the generated subtree
function_probability: f64Probability of selecting a function node for replacement
terminal_probability: f64Terminal probability for grow method
Implementations
Sourceimpl SubtreeMutation
impl SubtreeMutation
Sourcepub fn with_max_depth(self, depth: usize) -> Self
pub fn with_max_depth(self, depth: usize) -> Self
Set the maximum depth for generated subtrees
Sourcepub fn with_function_probability(self, probability: f64) -> Self
pub fn with_function_probability(self, probability: f64) -> Self
Set the function selection probability
Sourcepub fn with_terminal_probability(self, probability: f64) -> Self
pub fn with_terminal_probability(self, probability: f64) -> Self
Set the terminal probability for tree generation