pub trait CrossoverMask: Send + Sync {
// Required method
fn from_parent1(&self, addr: &Address) -> bool;
}Expand description
Trait for determining which parent contributes to each address during crossover
Required Methods
Sourcefn from_parent1(&self, addr: &Address) -> bool
fn from_parent1(&self, addr: &Address) -> bool
Returns true if parent1’s value should be used at the given address