pub enum TreeNode<T: Terminal, F: Function> {
Terminal(T),
Function(F, Vec<TreeNode<T, F>>),
}Expand description
A node in a GP tree
Variants
Implementations
Sourceimpl<T: Terminal, F: Function> TreeNode<T, F>
impl<T: Terminal, F: Function> TreeNode<T, F>
Sourcepub fn is_terminal(&self) -> bool
pub fn is_terminal(&self) -> bool
Check if this is a terminal node
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this is a function node
Sourcepub fn depth(&self) -> usize
pub fn depth(&self) -> usize
Get the depth of this subtree.
Uses an explicit work stack rather than recursion so that pathologically deep trees cannot overflow the call stack (see the module note on deep trees).
Sourcepub fn size(&self) -> usize
pub fn size(&self) -> usize
Get the number of nodes in this subtree.
Uses an explicit work stack rather than recursion (see the module note on deep trees).
Sourcepub fn get_subtree(&self, path: &[usize]) -> Option<&Self>
pub fn get_subtree(&self, path: &[usize]) -> Option<&Self>
Get a subtree at the given path
Sourcepub fn get_subtree_mut(&mut self, path: &[usize]) -> Option<&mut Self>
pub fn get_subtree_mut(&mut self, path: &[usize]) -> Option<&mut Self>
Get a mutable subtree at the given path
Sourcepub fn replace_subtree(&mut self, path: &[usize], new_subtree: Self) -> bool
pub fn replace_subtree(&mut self, path: &[usize], new_subtree: Self) -> bool
Replace a subtree at the given path
Sourcepub fn terminal_positions(&self) -> Vec<Vec<usize>>
pub fn terminal_positions(&self) -> Vec<Vec<usize>>
Get all terminal positions
Sourcepub fn function_positions(&self) -> Vec<Vec<usize>>
pub fn function_positions(&self) -> Vec<Vec<usize>>
Get all function positions