StrategyParams

Enum StrategyParams 

pub enum StrategyParams {
    Isotropic(f64),
    NonIsotropic(Vec<f64>),
    Correlated {
        sigmas: Vec<f64>,
        rotations: Vec<f64>,
    },
}
Strategy parameters that can be evolved alongside the genome

Variants



Isotropic(f64)

Single global step size (σ) - (1, σ)-ES or simple ES



NonIsotropic(Vec<f64>)

Per-gene step sizes (σ₁, …, σₙ) - Non-isotropic mutation



Correlated

Full covariance with rotation angles Contains step sizes (σ₁, …, σₙ) and rotation angles (α₁, …, αₖ) where k = n(n-1)/2

Fields

sigmas: Vec<f64>
rotations: Vec<f64>

Implementations

Source

impl StrategyParams

pub fn isotropic(sigma: f64) -> Self

Create isotropic parameters with given step size

pub fn non_isotropic(sigmas: Vec<f64>) -> Self

Create non-isotropic parameters with given step sizes

pub fn correlated(sigmas: Vec<f64>) -> Self

Create correlated parameters

pub fn dimension(&self) -> usize

Get dimension of the strategy parameters

pub fn mutate<R: Rng>(&mut self, n: usize, rng: &mut R)

Mutate the strategy parameters using log-normal distribution

τ = 1/√(2n) - global learning rate τ’ = 1/√(2√n) - local learning rate

pub fn get_sigma(&self, gene_idx: usize) -> f64

Get step size for a specific gene (for non-isotropic and correlated)

pub fn sigmas(&self) -> Vec<f64>

Get all step sizes