pub enum StrategyParams {
Isotropic(f64),
NonIsotropic(Vec<f64>),
Correlated {
sigmas: Vec<f64>,
rotations: Vec<f64>,
},
}Expand description
Strategy parameters that can be evolved alongside the genome
Variants
Isotropic(f64)
Single global step size (σ) - (1, σ)-ES or simple ES
NonIsotropic(Vec<f64>)
Per-gene step sizes (σ₁, …, σₙ) - Non-isotropic mutation
Full covariance with rotation angles Contains step sizes (σ₁, …, σₙ) and rotation angles (α₁, …, αₖ) where k = n(n-1)/2
Implementations
Sourceimpl StrategyParams
impl StrategyParams
Sourcepub fn non_isotropic(sigmas: Vec<f64>) -> Self
pub fn non_isotropic(sigmas: Vec<f64>) -> Self
Create non-isotropic parameters with given step sizes
Create correlated parameters
Sourcepub fn mutate<R: Rng>(&mut self, n: usize, rng: &mut R)
pub fn mutate<R: Rng>(&mut self, n: usize, rng: &mut R)
Mutate the strategy parameters using log-normal distribution
τ = 1/√(2n) - global learning rate τ’ = 1/√(2√n) - local learning rate