pub struct BayesianAdaptiveGA<P, F>{ /* private fields */ }Expand description
A single-level Bayesian adaptive genetic algorithm.
See the module docs for the model. Operator step sizes are selected
by Thompson sampling over per-operator Beta success posteriors, which are
updated by conjugate Bayesian updates from observed improvement events.
Implementations
Sourceimpl<P, F> BayesianAdaptiveGA<P, F>
impl<P, F> BayesianAdaptiveGA<P, F>
Sourcepub fn new(
prior: P,
fitness: F,
population_size: usize,
generations: usize,
) -> Self
pub fn new( prior: P, fitness: F, population_size: usize, generations: usize, ) -> Self
Create a new adaptive GA with a default set of mutation step sizes.
Sourcepub fn with_step_sizes(self, sigmas: Vec<f64>) -> Self
pub fn with_step_sizes(self, sigmas: Vec<f64>) -> Self
Replace the operator step sizes (each gets a fresh Beta(1, 1) prior).
Sourcepub fn with_mutation_rate(self, rate: f64) -> Self
pub fn with_mutation_rate(self, rate: f64) -> Self
Set the coordinate mutation probability.
Sourcepub fn with_tournament_size(self, size: usize) -> Self
pub fn with_tournament_size(self, size: usize) -> Self
Set the tournament size for parent selection.