pub struct DefaultInteractiveFitness<G>where
G: EvolutionaryGenome,{ /* private fields */ }Expand description
Default interactive fitness implementation using a fixed evaluation mode
This provides a simple implementation that delegates all processing to the fitness aggregator. Suitable for most use cases.
Implementations
Sourceimpl<G> DefaultInteractiveFitness<G>where
G: EvolutionaryGenome,
impl<G> DefaultInteractiveFitness<G>where
G: EvolutionaryGenome,
Sourcepub fn new(mode: EvaluationMode) -> Self
pub fn new(mode: EvaluationMode) -> Self
Create a new default interactive fitness with the given mode
Sourcepub fn with_batch_size(self, size: usize) -> Self
pub fn with_batch_size(self, size: usize) -> Self
Set the batch size for batch selection mode
Sourcepub fn with_select_count(self, count: usize) -> Self
pub fn with_select_count(self, count: usize) -> Self
Set how many candidates to select in batch selection mode